# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: configrelease.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from ..service_manage import service_pb2 as service__pb2
from ..fault_tolerance import circuitbreaker_pb2 as circuitbreaker__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63onfigrelease.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\rservice.proto\x1a\x14\x63ircuitbreaker.proto\"\xb3\x01\n\rConfigRelease\x12\x1c\n\x07service\x18\x01 \x01(\x0b\x32\x0b.v1.Service\x12+\n\x05\x63time\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x0e\x63ircuitBreaker\x18\x04 \x01(\x0b\x32\x12.v1.CircuitBreaker\"^\n\x11\x43onfigWithService\x12\x1d\n\x08services\x18\x01 \x03(\x0b\x32\x0b.v1.Service\x12*\n\x0e\x63ircuitBreaker\x18\x02 \x01(\x0b\x32\x12.v1.CircuitBreakerB\x93\x01\n7com.tencent.polaris.specification.api.v1.service.manageB\x12\x43onfigReleaseProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'configrelease_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.service.manageB\022ConfigReleaseProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manage'
  _globals['_CONFIGRELEASE']._serialized_start=97
  _globals['_CONFIGRELEASE']._serialized_end=276
  _globals['_CONFIGWITHSERVICE']._serialized_start=278
  _globals['_CONFIGWITHSERVICE']._serialized_end=372
# @@protoc_insertion_point(module_scope)
