# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from ..model import namespace_pb2 as namespace__pb2
from ..service_manage import service_pb2 as service__pb2
from ..traffic_manage import routing_pb2 as routing__pb2
from ..traffic_manage import ratelimit_pb2 as ratelimit__pb2
from ..fault_tolerance import circuitbreaker_pb2 as circuitbreaker__pb2
from ..model import model_pb2 as model__pb2
from ..service_manage import client_pb2 as client__pb2
from ..service_manage import configrelease_pb2 as configrelease__pb2
from ..fault_tolerance import fault_detector_pb2 as fault__detector__pb2
from ..security import auth_pb2 as auth__pb2
from ..service_manage import contract_pb2 as contract__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eresponse.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x19google/protobuf/any.proto\x1a\x0fnamespace.proto\x1a\rservice.proto\x1a\rrouting.proto\x1a\x0fratelimit.proto\x1a\x14\x63ircuitbreaker.proto\x1a\x0bmodel.proto\x1a\x0c\x63lient.proto\x1a\x13\x63onfigrelease.proto\x1a\x14\x66\x61ult_detector.proto\x1a\nauth.proto\x1a\x0e\x63ontract.proto\"\xcf\x06\n\x08Response\x12*\n\x04\x63ode\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04info\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1a\n\x06\x63lient\x18\x03 \x01(\x0b\x32\n.v1.Client\x12 \n\tnamespace\x18\x04 \x01(\x0b\x32\r.v1.Namespace\x12\x1c\n\x07service\x18\x05 \x01(\x0b\x32\x0b.v1.Service\x12\x1e\n\x08instance\x18\x06 \x01(\x0b\x32\x0c.v1.Instance\x12\x1c\n\x07routing\x18\x07 \x01(\x0b\x32\x0b.v1.Routing\x12\x1f\n\x05\x61lias\x18\x08 \x01(\x0b\x32\x10.v1.ServiceAlias\x12\x1b\n\trateLimit\x18\t \x01(\x0b\x32\x08.v1.Rule\x12*\n\x0e\x63ircuitBreaker\x18\n \x01(\x0b\x32\x12.v1.CircuitBreaker\x12(\n\rconfigRelease\x18\x0b \x01(\x0b\x32\x11.v1.ConfigRelease\x12\x16\n\x04user\x18\x13 \x01(\x0b\x32\x08.v1.User\x12 \n\tuserGroup\x18\x14 \x01(\x0b\x32\r.v1.UserGroup\x12&\n\x0c\x61uthStrategy\x18\x15 \x01(\x0b\x32\x10.v1.AuthStrategy\x12\'\n\x08relation\x18\x16 \x01(\x0b\x32\x15.v1.UserGroupRelation\x12(\n\rloginResponse\x18\x17 \x01(\x0b\x32\x11.v1.LoginResponse\x12\x32\n\x12modifyAuthStrategy\x18\x18 \x01(\x0b\x32\x16.v1.ModifyAuthStrategy\x12,\n\x0fmodifyUserGroup\x18\x19 \x01(\x0b\x32\x13.v1.ModifyUserGroup\x12(\n\tresources\x18\x1a \x01(\x0b\x32\x15.v1.StrategyResources\x12&\n\x0coptionSwitch\x18\x1b \x01(\x0b\x32\x10.v1.OptionSwitch\x12*\n\x0einstanceLabels\x18\x1c \x01(\x0b\x32\x12.v1.InstanceLabels\x12\"\n\x04\x64\x61ta\x18\x1d \x01(\x0b\x32\x14.google.protobuf.AnyJ\x04\x08\x0c\x10\x13\"\xb9\x01\n\x12\x42\x61tchWriteResponse\x12*\n\x04\x63ode\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04info\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04size\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x1f\n\tresponses\x18\x04 \x03(\x0b\x32\x0c.v1.Response\"\x87\x05\n\x12\x42\x61tchQueryResponse\x12*\n\x04\x63ode\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04info\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04size\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12!\n\nnamespaces\x18\x05 \x03(\x0b\x32\r.v1.Namespace\x12\x1d\n\x08services\x18\x06 \x03(\x0b\x32\x0b.v1.Service\x12\x1f\n\tinstances\x18\x07 \x03(\x0b\x32\x0c.v1.Instance\x12\x1d\n\x08routings\x18\x08 \x03(\x0b\x32\x0b.v1.Routing\x12!\n\x07\x61liases\x18\t \x03(\x0b\x32\x10.v1.ServiceAlias\x12\x1c\n\nrateLimits\x18\n \x03(\x0b\x32\x08.v1.Rule\x12\x31\n\x12\x63onfigWithServices\x18\x0b \x03(\x0b\x32\x15.v1.ConfigWithService\x12\x17\n\x05users\x18\x12 \x03(\x0b\x32\x08.v1.User\x12!\n\nuserGroups\x18\x13 \x03(\x0b\x32\r.v1.UserGroup\x12(\n\x0e\x61uthStrategies\x18\x14 \x03(\x0b\x32\x10.v1.AuthStrategy\x12\x1b\n\x07\x63lients\x18\x15 \x03(\x0b\x32\n.v1.Client\x12\"\n\x04\x64\x61ta\x18\x16 \x03(\x0b\x32\x14.google.protobuf.Any\x12\x1c\n\x07summary\x18\x17 \x01(\x0b\x32\x0b.v1.SummaryJ\x04\x08\x0c\x10\x12\"\x88\x06\n\x10\x44iscoverResponse\x12*\n\x04\x63ode\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04info\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x04type\x18\x03 \x01(\x0e\x32).v1.DiscoverResponse.DiscoverResponseType\x12\x1c\n\x07service\x18\x04 \x01(\x0b\x32\x0b.v1.Service\x12\x1f\n\tinstances\x18\x05 \x03(\x0b\x32\x0c.v1.Instance\x12\x1c\n\x07routing\x18\x06 \x01(\x0b\x32\x0b.v1.Routing\x12 \n\trateLimit\x18\x07 \x01(\x0b\x32\r.v1.RateLimit\x12*\n\x0e\x63ircuitBreaker\x18\x08 \x01(\x0b\x32\x12.v1.CircuitBreaker\x12\x1d\n\x08services\x18\t \x03(\x0b\x32\x0b.v1.Service\x12!\n\nnamespaces\x18\n \x03(\x0b\x32\r.v1.Namespace\x12(\n\rfaultDetector\x18\x0b \x01(\x0b\x32\x11.v1.FaultDetector\x12\x1d\n\x08\x61liasFor\x18\x15 \x01(\x0b\x32\x0b.v1.Service\x12,\n\x0fserviceContract\x18\x16 \x01(\x0b\x32\x13.v1.ServiceContract\"\xf8\x01\n\x14\x44iscoverResponseType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08INSTANCE\x10\x01\x12\x0b\n\x07\x43LUSTER\x10\x02\x12\x0b\n\x07ROUTING\x10\x03\x12\x0e\n\nRATE_LIMIT\x10\x04\x12\x13\n\x0f\x43IRCUIT_BREAKER\x10\x05\x12\x0c\n\x08SERVICES\x10\x06\x12\x0e\n\nNAMESPACES\x10\x0c\x12\x12\n\x0e\x46\x41ULT_DETECTOR\x10\r\x12\x14\n\x10SERVICE_CONTRACT\x10\x0e\"\x04\x08\x07\x10\x0b*\x04MESH*\x0bMESH_CONFIG*\x0e\x46LUX_DBREFRESH*\x08\x46LUX_SDK*\x0b\x46LUX_SERVERJ\x04\x08\x0c\x10\x15\"n\n\x0cOptionSwitch\x12.\n\x07options\x18\x01 \x03(\x0b\x32\x1d.v1.OptionSwitch.OptionsEntry\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x7f\n\x0eInstanceLabels\x12.\n\x06labels\x18\x01 \x03(\x0b\x32\x1e.v1.InstanceLabels.LabelsEntry\x1a=\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.v1.StringList:\x02\x38\x01\x42\x8e\x01\n7com.tencent.polaris.specification.api.v1.service.manageB\rResponseProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.service.manageB\rResponseProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manage'
  _OPTIONSWITCH_OPTIONSENTRY._options = None
  _OPTIONSWITCH_OPTIONSENTRY._serialized_options = b'8\001'
  _INSTANCELABELS_LABELSENTRY._options = None
  _INSTANCELABELS_LABELSENTRY._serialized_options = b'8\001'
  _globals['_RESPONSE']._serialized_start=266
  _globals['_RESPONSE']._serialized_end=1113
  _globals['_BATCHWRITERESPONSE']._serialized_start=1116
  _globals['_BATCHWRITERESPONSE']._serialized_end=1301
  _globals['_BATCHQUERYRESPONSE']._serialized_start=1304
  _globals['_BATCHQUERYRESPONSE']._serialized_end=1951
  _globals['_DISCOVERRESPONSE']._serialized_start=1954
  _globals['_DISCOVERRESPONSE']._serialized_end=2730
  _globals['_DISCOVERRESPONSE_DISCOVERRESPONSETYPE']._serialized_start=2476
  _globals['_DISCOVERRESPONSE_DISCOVERRESPONSETYPE']._serialized_end=2724
  _globals['_OPTIONSWITCH']._serialized_start=2732
  _globals['_OPTIONSWITCH']._serialized_end=2842
  _globals['_OPTIONSWITCH_OPTIONSENTRY']._serialized_start=2796
  _globals['_OPTIONSWITCH_OPTIONSENTRY']._serialized_end=2842
  _globals['_INSTANCELABELS']._serialized_start=2844
  _globals['_INSTANCELABELS']._serialized_end=2971
  _globals['_INSTANCELABELS_LABELSENTRY']._serialized_start=2910
  _globals['_INSTANCELABELS_LABELSENTRY']._serialized_end=2971
# @@protoc_insertion_point(module_scope)
