# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from ..model import model_pb2 as model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rservice.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x0bmodel.proto\"\x9f\x0b\n\x07Service\x12*\n\x04name\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x08metadata\x18\x03 \x03(\x0b\x32\x19.v1.Service.MetadataEntry\x12+\n\x05ports\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x62usiness\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\ndepartment\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\tcmdb_mod1\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tcmdb_mod1\x12:\n\tcmdb_mod2\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tcmdb_mod2\x12:\n\tcmdb_mod3\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tcmdb_mod3\x12-\n\x07\x63omment\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06owners\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05token\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x63time\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08revision\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12>\n\x0bplatform_id\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0bplatform_id\x12P\n\x14total_instance_count\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x14total_instance_count\x12T\n\x16healthy_instance_count\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x16healthy_instance_count\x12\x38\n\x08user_ids\x18\x13 \x03(\x0b\x32\x1c.google.protobuf.StringValueR\x08user_ids\x12:\n\tgroup_ids\x18\x14 \x03(\x0b\x32\x1c.google.protobuf.StringValueR\tgroup_ids\x12\x46\n\x0fremove_user_ids\x18\x16 \x03(\x0b\x32\x1c.google.protobuf.StringValueR\x0fremove_user_ids\x12H\n\x10remove_group_ids\x18\x17 \x03(\x0b\x32\x1c.google.protobuf.StringValueR\x10remove_group_ids\x12(\n\x02id\x18\x15 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x08\x65\x64itable\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12:\n\texport_to\x18\x19 \x03(\x0b\x32\x1c.google.protobuf.StringValueR\texport_to\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd3\x04\n\x0cServiceAlias\x12-\n\x07service\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x61lias\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x46\n\x0f\x61lias_namespace\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0f\x61lias_namespace\x12\x1b\n\x04type\x18\x05 \x01(\x0e\x32\r.v1.AliasType\x12,\n\x06owners\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63omment\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x42\n\rservice_token\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\rservice_token\x12+\n\x05\x63time\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12(\n\x02id\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x08\x65\x64itable\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xa2\x08\n\x08Instance\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07service\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x06vpc_id\x18\x15 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x06vpc_id\x12*\n\x04host\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04port\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12.\n\x08protocol\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07version\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08priority\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12,\n\x06weight\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x37\n\x13\x65nable_health_check\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12%\n\x0chealth_check\x18\n \x01(\x0b\x32\x0f.v1.HealthCheck\x12+\n\x07healthy\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\x07isolate\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1e\n\x08location\x18\r \x01(\x0b\x32\x0c.v1.Location\x12,\n\x08metadata\x18\x0e \x03(\x0b\x32\x1a.v1.Instance.MetadataEntry\x12:\n\tlogic_set\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tlogic_set\x12+\n\x05\x63time\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08revision\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x42\n\rservice_token\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\rservice_token\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x98\x01\n\x0bHealthCheck\x12-\n\x04type\x18\x01 \x01(\x0e\x32\x1f.v1.HealthCheck.HealthCheckType\x12+\n\theartbeat\x18\x02 \x01(\x0b\x32\x18.v1.HeartbeatHealthCheck\"-\n\x0fHealthCheckType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tHEARTBEAT\x10\x01\"A\n\x14HeartbeatHealthCheck\x12)\n\x03ttl\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value*$\n\tAliasType\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\n\n\x06\x43L5SID\x10\x01\x42\x8d\x01\n7com.tencent.polaris.specification.api.v1.service.manageB\x0cServiceProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.service.manageB\014ServiceProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manage'
  _SERVICE_METADATAENTRY._options = None
  _SERVICE_METADATAENTRY._serialized_options = b'8\001'
  _INSTANCE_METADATAENTRY._options = None
  _INSTANCE_METADATAENTRY._serialized_options = b'8\001'
  _globals['_ALIASTYPE']._serialized_start=3389
  _globals['_ALIASTYPE']._serialized_end=3425
  _globals['_SERVICE']._serialized_start=67
  _globals['_SERVICE']._serialized_end=1506
  _globals['_SERVICE_METADATAENTRY']._serialized_start=1459
  _globals['_SERVICE_METADATAENTRY']._serialized_end=1506
  _globals['_SERVICEALIAS']._serialized_start=1509
  _globals['_SERVICEALIAS']._serialized_end=2104
  _globals['_INSTANCE']._serialized_start=2107
  _globals['_INSTANCE']._serialized_end=3165
  _globals['_INSTANCE_METADATAENTRY']._serialized_start=1459
  _globals['_INSTANCE_METADATAENTRY']._serialized_end=1506
  _globals['_HEALTHCHECK']._serialized_start=3168
  _globals['_HEALTHCHECK']._serialized_end=3320
  _globals['_HEALTHCHECK_HEALTHCHECKTYPE']._serialized_start=3275
  _globals['_HEALTHCHECK_HEALTHCHECKTYPE']._serialized_end=3320
  _globals['_HEARTBEATHEALTHCHECK']._serialized_start=3322
  _globals['_HEARTBEATHEALTHCHECK']._serialized_end=3387
# @@protoc_insertion_point(module_scope)
