# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: client.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from ..model import model_pb2 as model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x63lient.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x0bmodel.proto\"\xf7\x02\n\x06\x43lient\x12*\n\x04host\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12#\n\x04type\x18\x02 \x01(\x0e\x32\x15.v1.Client.ClientType\x12-\n\x07version\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1e\n\x08location\x18\x04 \x01(\x0b\x32\x0c.v1.Location\x12(\n\x02id\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1a\n\x04stat\x18\x06 \x03(\x0b\x32\x0c.v1.StatInfo\x12+\n\x05\x63time\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"-\n\nClientType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03SDK\x10\x01\x12\t\n\x05\x41GENT\x10\x02\"\xc0\x01\n\x08StatInfo\x12,\n\x06target\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04port\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12*\n\x04path\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08protocol\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x8c\x01\n7com.tencent.polaris.specification.api.v1.service.manageB\x0b\x43lientProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'client_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.service.manageB\013ClientProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manage'
  _globals['_CLIENT']._serialized_start=66
  _globals['_CLIENT']._serialized_end=441
  _globals['_CLIENT_CLIENTTYPE']._serialized_start=396
  _globals['_CLIENT_CLIENTTYPE']._serialized_end=441
  _globals['_STATINFO']._serialized_start=444
  _globals['_STATINFO']._serialized_end=636
# @@protoc_insertion_point(module_scope)
