# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: code.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ncode.proto\x12\x02v1*\xbc%\n\x04\x43ode\x12\x0b\n\x07Unknown\x10\x00\x12\x14\n\x0e\x45xecuteSuccess\x10\xc0\x9a\x0c\x12\x12\n\x0c\x44\x61taNoChange\x10\xc1\x9a\x0c\x12\x12\n\x0cNoNeedUpdate\x10\xc2\x9a\x0c\x12\x10\n\nBadRequest\x10\x80\xb5\x18\x12\x14\n\x0eParseException\x10\x81\xb5\x18\x12\x12\n\x0c\x45mptyRequest\x10\x82\xb5\x18\x12\x18\n\x12\x42\x61tchSizeOverLimit\x10\x83\xb5\x18\x12\x1d\n\x17InvalidDiscoverResource\x10\x84\xb5\x18\x12\x16\n\x10InvalidRequestID\x10\xe4\xb5\x18\x12\x15\n\x0fInvalidUserName\x10\xe5\xb5\x18\x12\x16\n\x10InvalidUserToken\x10\xe6\xb5\x18\x12\x16\n\x10InvalidParameter\x10\xe7\xb5\x18\x12\x19\n\x13\x45mptyQueryParameter\x10\xe8\xb5\x18\x12\x1e\n\x18InvalidQueryInsParameter\x10\xe9\xb5\x18\x12\x1a\n\x14InvalidNamespaceName\x10\xee\xb5\x18\x12\x1c\n\x16InvalidNamespaceOwners\x10\xef\xb5\x18\x12\x1b\n\x15InvalidNamespaceToken\x10\xf0\xb5\x18\x12\x18\n\x12InvalidServiceName\x10\xf8\xb5\x18\x12\x1a\n\x14InvalidServiceOwners\x10\xf9\xb5\x18\x12\x19\n\x13InvalidServiceToken\x10\xfa\xb5\x18\x12\x1c\n\x16InvalidServiceMetadata\x10\xfb\xb5\x18\x12\x19\n\x13InvalidServicePorts\x10\xfc\xb5\x18\x12\x1c\n\x16InvalidServiceBusiness\x10\xfd\xb5\x18\x12\x1e\n\x18InvalidServiceDepartment\x10\xfe\xb5\x18\x12\x18\n\x12InvalidServiceCMDB\x10\xff\xb5\x18\x12\x1b\n\x15InvalidServiceComment\x10\x80\xb6\x18\x12 \n\x1aInvalidServiceAliasComment\x10\x81\xb6\x18\x12\x17\n\x11InvalidInstanceID\x10\x82\xb6\x18\x12\x19\n\x13InvalidInstanceHost\x10\x83\xb6\x18\x12\x19\n\x13InvalidInstancePort\x10\x84\xb6\x18\x12\x19\n\x13InvalidServiceAlias\x10\x85\xb6\x18\x12\x1f\n\x19InvalidNamespaceWithAlias\x10\x86\xb6\x18\x12\x1f\n\x19InvalidServiceAliasOwners\x10\x87\xb6\x18\x12\x1d\n\x17InvalidInstanceProtocol\x10\x88\xb6\x18\x12\x1c\n\x16InvalidInstanceVersion\x10\x89\xb6\x18\x12\x1d\n\x17InvalidInstanceLogicSet\x10\x8a\xb6\x18\x12\x1c\n\x16InvalidInstanceIsolate\x10\x8b\xb6\x18\x12\x18\n\x12HealthCheckNotOpen\x10\x8c\xb6\x18\x12\x1c\n\x16HeartbeatOnDisabledIns\x10\x8d\xb6\x18\x12\x1a\n\x14HeartbeatExceedLimit\x10\x8e\xb6\x18\x12\x1b\n\x15HeartbeatTypeNotFound\x10\x8f\xb6\x18\x12\x15\n\x0fInvalidMetadata\x10\x96\xb6\x18\x12\x18\n\x12InvalidRateLimitID\x10\x97\xb6\x18\x12\x1c\n\x16InvalidRateLimitLabels\x10\x98\xb6\x18\x12\x1d\n\x17InvalidRateLimitAmounts\x10\x99\xb6\x18\x12\x1a\n\x14InvalidRateLimitName\x10\x9a\xb6\x18\x12\x1d\n\x17InvalidCircuitBreakerID\x10\xa0\xb6\x18\x12\"\n\x1cInvalidCircuitBreakerVersion\x10\xa1\xb6\x18\x12\x1f\n\x19InvalidCircuitBreakerName\x10\xa2\xb6\x18\x12$\n\x1eInvalidCircuitBreakerNamespace\x10\xa3\xb6\x18\x12!\n\x1bInvalidCircuitBreakerOwners\x10\xa4\xb6\x18\x12 \n\x1aInvalidCircuitBreakerToken\x10\xa5\xb6\x18\x12#\n\x1dInvalidCircuitBreakerBusiness\x10\xa6\xb6\x18\x12%\n\x1fInvalidCircuitBreakerDepartment\x10\xa7\xb6\x18\x12\"\n\x1cInvalidCircuitBreakerComment\x10\xa8\xb6\x18\x12\x1f\n\x19\x43ircuitBreakerRuleExisted\x10\xa9\xb6\x18\x12\x16\n\x10InvalidRoutingID\x10\xbc\xba\x18\x12\x1a\n\x14InvalidRoutingPolicy\x10\xbd\xba\x18\x12\x18\n\x12InvalidRoutingName\x10\xbe\xba\x18\x12\x1c\n\x16InvalidRoutingPriority\x10\xbf\xba\x18\x12\x1a\n\x14InvalidFaultDetectID\x10\x84\xbc\x18\x12\x1c\n\x16InvalidFaultDetectName\x10\x85\xbc\x18\x12!\n\x1bInvalidFaultDetectNamespace\x10\x86\xbc\x18\x12\x1c\n\x16\x46\x61ultDetectRuleExisted\x10\x87\xbc\x18\x12\x16\n\x10InvalidMatchRule\x10\x88\xbc\x18\x12\x19\n\x13ServicesExistedMesh\x10\xaa\xb6\x18\x12\x1a\n\x14ResourcesExistedMesh\x10\xab\xb6\x18\x12\x1a\n\x14InvalidMeshParameter\x10\xac\xb6\x18\x12\x17\n\x11InvalidPlatformID\x10\xb4\xb6\x18\x12\x19\n\x13InvalidPlatformName\x10\xb5\xb6\x18\x12\x1b\n\x15InvalidPlatformDomain\x10\xb6\xb6\x18\x12\x18\n\x12InvalidPlatformQPS\x10\xb7\xb6\x18\x12\x1a\n\x14InvalidPlatformToken\x10\xb8\xb6\x18\x12\x1a\n\x14InvalidPlatformOwner\x10\xb9\xb6\x18\x12\x1f\n\x19InvalidPlatformDepartment\x10\xba\xb6\x18\x12\x1c\n\x16InvalidPlatformComment\x10\xbb\xb6\x18\x12\x16\n\x10NotFoundPlatform\x10\xbc\xb6\x18\x12\x1c\n\x16InvalidFluxRateLimitId\x10\xbe\xb6\x18\x12\x1d\n\x17InvalidFluxRateLimitQps\x10\xbf\xb6\x18\x12 \n\x1aInvalidFluxRateLimitSetKey\x10\xc0\xb6\x18\x12\x15\n\x0f\x45xistedResource\x10\xc9\xb6\x18\x12\x16\n\x10NotFoundResource\x10\xca\xb6\x18\x12\x1e\n\x18NamespaceExistedServices\x10\xcb\xb6\x18\x12\x1d\n\x17ServiceExistedInstances\x10\xcc\xb6\x18\x12\x1c\n\x16ServiceExistedRoutings\x10\xcd\xb6\x18\x12\x1e\n\x18ServiceExistedRateLimits\x10\xce\xb6\x18\x12\x19\n\x13\x45xistReleasedConfig\x10\xcf\xb6\x18\x12\x19\n\x13SameInstanceRequest\x10\xd0\xb6\x18\x12#\n\x1dServiceExistedCircuitBreakers\x10\xd1\xb6\x18\x12\x19\n\x13ServiceExistedAlias\x10\xd2\xb6\x18\x12#\n\x1dNamespaceExistedMeshResources\x10\xd3\xb6\x18\x12%\n\x1fNamespaceExistedCircuitBreakers\x10\xd4\xb6\x18\x12\x1f\n\x19ServiceSubscribedByMeshes\x10\xd5\xb6\x18\x12\"\n\x1cServiceExistedFluxRateLimits\x10\xd6\xb6\x18\x12\"\n\x1cNamespaceExistedConfigGroups\x10\xdb\xb6\x18\x12\x15\n\x0fNotFoundService\x10\xad\xb7\x18\x12\x15\n\x0fNotFoundRouting\x10\xae\xb7\x18\x12\x16\n\x10NotFoundInstance\x10\xaf\xb7\x18\x12\x1a\n\x14NotFoundServiceAlias\x10\xb0\xb7\x18\x12\x17\n\x11NotFoundNamespace\x10\xb1\xb7\x18\x12\x1b\n\x15NotFoundSourceService\x10\xb2\xb7\x18\x12\x17\n\x11NotFoundRateLimit\x10\xb3\xb7\x18\x12\x1c\n\x16NotFoundCircuitBreaker\x10\xb4\xb7\x18\x12\x1a\n\x14NotFoundMasterConfig\x10\xb5\xb7\x18\x12\x17\n\x11NotFoundTagConfig\x10\xb6\xb7\x18\x12 \n\x1aNotFoundTagConfigOrService\x10\xb7\xb7\x18\x12\x16\n\x10\x43lientAPINotOpen\x10\x91\xb8\x18\x12\x1d\n\x17NotAllowBusinessService\x10\x92\xb8\x18\x12\x19\n\x13NotAllowAliasUpdate\x10\xf5\xb8\x18\x12!\n\x1bNotAllowAliasCreateInstance\x10\xf6\xb8\x18\x12 \n\x1aNotAllowAliasCreateRouting\x10\xf7\xb8\x18\x12!\n\x1bNotAllowCreateAliasForAlias\x10\xf8\xb8\x18\x12\"\n\x1cNotAllowAliasCreateRateLimit\x10\xf9\xb8\x18\x12\x1b\n\x15NotAllowAliasBindRule\x10\xfa\xb8\x18\x12(\n\"NotAllowDifferentNamespaceBindRule\x10\xfb\xb8\x18\x12\x12\n\x0cUnauthorized\x10\xe8\xbc\x18\x12\x16\n\x10NotAllowedAccess\x10\xe9\xbc\x18\x12\x15\n\x0f\x43MDBNotFindHost\x10\xa1\xd4\x18\x12\x12\n\x0c\x44\x61taConflict\x10\xa8\xfb\x18\x12\x1d\n\x17InstanceTooManyRequests\x10\xc9\x97\x1a\x12\x11\n\x0bIPRateLimit\x10\xca\x97\x1a\x12\x12\n\x0c\x41PIRateLimit\x10\xbb\xcc\x18\x12\x16\n\x10\x45xecuteException\x10\xa0\xc2\x1e\x12\x19\n\x13StoreLayerException\x10\xa1\xc2\x1e\x12\x19\n\x13\x43MDBPluginException\x10\xa2\xc2\x1e\x12\x1b\n\x15ParseRoutingException\x10\xa4\xc2\x1e\x12\x1d\n\x17ParseRateLimitException\x10\xa5\xc2\x1e\x12\"\n\x1cParseCircuitBreakerException\x10\xa6\xc2\x1e\x12\x18\n\x12HeartbeatException\x10\xa7\xc2\x1e\x12\x1a\n\x14InstanceRegisTimeout\x10\xa8\xc2\x1e\x12 \n\x1aInvalidConfigFileGroupName\x10\xa1\xbb\x18\x12\x1b\n\x15InvalidConfigFileName\x10\xa2\xbb\x18\x12$\n\x1eInvalidConfigFileContentLength\x10\xa3\xbb\x18\x12\x1d\n\x17InvalidConfigFileFormat\x10\xa4\xbb\x18\x12\x1b\n\x15InvalidConfigFileTags\x10\xa5\xbb\x18\x12\"\n\x1cInvalidWatchConfigFileFormat\x10\xa6\xbb\x18\x12 \n\x1aNotFoundResourceConfigFile\x10\xa7\xbb\x18\x12#\n\x1dInvalidConfigFileTemplateName\x10\xa8\xbb\x18\x12 \n\x1a\x45ncryptConfigFileException\x10\xa9\xbb\x18\x12 \n\x1a\x44\x65\x63ryptConfigFileException\x10\xaa\xbb\x18\x12\x17\n\x11InvalidUserOwners\x10\x9a\xb8\x18\x12\x13\n\rInvalidUserID\x10\x9b\xb8\x18\x12\x19\n\x13InvalidUserPassword\x10\x9c\xb8\x18\x12\x17\n\x11InvalidUserMobile\x10\x9d\xb8\x18\x12\x16\n\x10InvalidUserEmail\x10\x9e\xb8\x18\x12\x1c\n\x16InvalidUserGroupOwners\x10\xa4\xb8\x18\x12\x18\n\x12InvalidUserGroupID\x10\xa5\xb8\x18\x12\x1f\n\x19InvalidAuthStrategyOwners\x10\xae\xb8\x18\x12\x1d\n\x17InvalidAuthStrategyName\x10\xaf\xb8\x18\x12\x1b\n\x15InvalidAuthStrategyID\x10\xb0\xb8\x18\x12\x1a\n\x14InvalidPrincipalType\x10\xb8\xb8\x18\x12\x11\n\x0bUserExisted\x10\xd7\xb6\x18\x12\x16\n\x10UserGroupExisted\x10\xd8\xb6\x18\x12\x1d\n\x17\x41uthStrategyRuleExisted\x10\xd9\xb6\x18\x12\x17\n\x11SubAccountExisted\x10\xda\xb6\x18\x12\x12\n\x0cNotFoundUser\x10\xb8\xb7\x18\x12\x17\n\x11NotFoundOwnerUser\x10\xb9\xb7\x18\x12\x17\n\x11NotFoundUserGroup\x10\xba\xb7\x18\x12\x1e\n\x18NotFoundAuthStrategyRule\x10\xbb\xb7\x18\x12,\n&NotAllowModifyDefaultStrategyPrincipal\x10\xfc\xb8\x18\x12(\n\"NotAllowModifyOwnerDefaultStrategy\x10\xfd\xb8\x18\x12\x13\n\rEmptyAutToken\x10\xea\xbc\x18\x12\x13\n\rTokenDisabled\x10\xeb\xbc\x18\x12\x15\n\x0fTokenNotExisted\x10\xec\xbc\x18\x12\x18\n\x12\x41uthTokenForbidden\x10\xb9\xcc\x18\x12\x1c\n\x16OperationRoleForbidden\x10\xba\xcc\x18\x42x\n.com.tencent.polaris.specification.api.v1.modelB\tCodeProtoZ;github.com/polarismesh/specification/source/go/api/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'code_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.com.tencent.polaris.specification.api.v1.modelB\tCodeProtoZ;github.com/polarismesh/specification/source/go/api/v1/model'
  _globals['_CODE']._serialized_start=19
  _globals['_CODE']._serialized_end=4815
# @@protoc_insertion_point(module_scope)
