# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ratelimit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from ..model import model_pb2 as model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fratelimit.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x0bmodel.proto\"T\n\tRateLimit\x12\x17\n\x05rules\x18\x01 \x03(\x0b\x32\x08.v1.Rule\x12.\n\x08revision\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xa9\x0b\n\x04Rule\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07service\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12$\n\x06subset\x18\x04 \x03(\x0b\x32\x14.v1.Rule.SubsetEntry\x12.\n\x08priority\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12#\n\x08resource\x18\x06 \x01(\x0e\x32\x11.v1.Rule.Resource\x12\x1b\n\x04type\x18\x07 \x01(\x0e\x32\r.v1.Rule.Type\x12$\n\x06labels\x18\x08 \x03(\x0b\x32\x14.v1.Rule.LabelsEntry\x12\x1b\n\x07\x61mounts\x18\t \x03(\x0b\x32\n.v1.Amount\x12,\n\x06\x61\x63tion\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x07\x64isable\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1a\n\x06report\x18\x0c \x01(\x0b\x32\n.v1.Report\x12+\n\x05\x63time\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08revision\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x42\n\rservice_token\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\rservice_token\x12$\n\x08\x61\x64juster\x18\x11 \x01(\x0b\x32\x12.v1.AmountAdjuster\x12@\n\rregex_combine\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\rregex_combine\x12(\n\x0b\x61mount_mode\x18\x13 \x01(\x0e\x32\x13.v1.Rule.AmountMode\x12\'\n\x08\x66\x61ilover\x18\x14 \x01(\x0e\x32\x15.v1.Rule.FailoverType\x12%\n\x07\x63luster\x18\x15 \x01(\x0b\x32\x14.v1.RateLimitCluster\x12\x1f\n\x06method\x18\x16 \x01(\x0b\x32\x0f.v1.MatchString\x12$\n\targuments\x18\x17 \x03(\x0b\x32\x11.v1.MatchArgument\x12*\n\x04name\x18\x18 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x65time\x18\x19 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x46\n\x0fmax_queue_delay\x18\x1a \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0fmax_queue_delay\x1a>\n\x0bSubsetEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.v1.MatchString:\x02\x38\x01\x1a>\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.v1.MatchString:\x02\x38\x01\"$\n\x08Resource\x12\x07\n\x03QPS\x10\x00\x12\x0f\n\x0b\x43ONCURRENCY\x10\x01\"\x1d\n\x04Type\x12\n\n\x06GLOBAL\x10\x00\x12\t\n\x05LOCAL\x10\x01\"1\n\nAmountMode\x12\x10\n\x0cGLOBAL_TOTAL\x10\x00\x12\x11\n\rSHARE_EQUALLY\x10\x01\"5\n\x0c\x46\x61iloverType\x12\x12\n\x0e\x46\x41ILOVER_LOCAL\x10\x00\x12\x11\n\rFAILOVER_PASS\x10\x01\"\xbc\x01\n\rMatchArgument\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.v1.MatchArgument.Type\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x1e\n\x05value\x18\x03 \x01(\x0b\x32\x0f.v1.MatchString\"X\n\x04Type\x12\n\n\x06\x43USTOM\x10\x00\x12\n\n\x06METHOD\x10\x01\x12\n\n\x06HEADER\x10\x02\x12\t\n\x05QUERY\x10\x03\x12\x12\n\x0e\x43\x41LLER_SERVICE\x10\x04\x12\r\n\tCALLER_IP\x10\x05\"r\n\x10RateLimitCluster\x12-\n\x07service\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x80\x02\n\x06\x41mount\x12/\n\tmaxAmount\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x30\n\rvalidDuration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\tprecision\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x31\n\x0bstartAmount\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12/\n\tminAmount\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\"j\n\x06Report\x12+\n\x08interval\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x33\n\ramountPercent\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\"0\n\x0e\x41mountAdjuster\x12\x1e\n\x05\x63limb\x18\x01 \x01(\x0b\x32\x0f.v1.ClimbConfig\"\xec\x0b\n\x0b\x43limbConfig\x12*\n\x06\x65nable\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x06metric\x18\x02 \x01(\x0b\x32\x1c.v1.ClimbConfig.MetricConfig\x12-\n\x06policy\x18\x03 \x01(\x0b\x32\x1d.v1.ClimbConfig.TriggerPolicy\x12\x33\n\nthrottling\x18\x04 \x01(\x0b\x32\x1f.v1.ClimbConfig.ClimbThrottling\x1a\x9d\x01\n\x0cMetricConfig\x12)\n\x06window\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\tprecision\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x31\n\x0ereportInterval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x1a\xa7\x05\n\rTriggerPolicy\x12:\n\terrorRate\x18\x01 \x01(\x0b\x32\'.v1.ClimbConfig.TriggerPolicy.ErrorRate\x12\x38\n\x08slowRate\x18\x02 \x01(\x0b\x32&.v1.ClimbConfig.TriggerPolicy.SlowRate\x1a\x8d\x03\n\tErrorRate\x12*\n\x06\x65nable\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12<\n\x16requestVolumeThreshold\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12.\n\terrorRate\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12G\n\x08specials\x18\x04 \x03(\x0b\x32\x35.v1.ClimbConfig.TriggerPolicy.ErrorRate.SpecialConfig\x1a\x9c\x01\n\rSpecialConfig\x12*\n\x04type\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\nerrorCodes\x18\x02 \x03(\x0b\x32\x1b.google.protobuf.Int64Value\x12.\n\terrorRate\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x1a\x8f\x01\n\x08SlowRate\x12*\n\x06\x65nable\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12(\n\x05maxRt\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12-\n\x08slowRate\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x1a\xd4\x03\n\x0f\x43limbThrottling\x12:\n\x15\x63oldBelowTuneDownRate\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x38\n\x13\x63oldBelowTuneUpRate\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12:\n\x15\x63oldAboveTuneDownRate\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x38\n\x13\x63oldAboveTuneUpRate\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12;\n\x16limitThresholdToTuneUp\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x30\n\rjudgeDuration\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x31\n\x0ctuneUpPeriod\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x33\n\x0etuneDownPeriod\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\x8f\x01\n7com.tencent.polaris.specification.api.v1.traffic.manageB\x0eRateLimitProtoZDgithub.com/polarismesh/specification/source/go/api/v1/traffic_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ratelimit_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.traffic.manageB\016RateLimitProtoZDgithub.com/polarismesh/specification/source/go/api/v1/traffic_manage'
  _RULE_SUBSETENTRY._options = None
  _RULE_SUBSETENTRY._serialized_options = b'8\001'
  _RULE_LABELSENTRY._options = None
  _RULE_LABELSENTRY._serialized_options = b'8\001'
  _globals['_RATELIMIT']._serialized_start=100
  _globals['_RATELIMIT']._serialized_end=184
  _globals['_RULE']._serialized_start=187
  _globals['_RULE']._serialized_end=1636
  _globals['_RULE_SUBSETENTRY']._serialized_start=1335
  _globals['_RULE_SUBSETENTRY']._serialized_end=1397
  _globals['_RULE_LABELSENTRY']._serialized_start=1399
  _globals['_RULE_LABELSENTRY']._serialized_end=1461
  _globals['_RULE_RESOURCE']._serialized_start=1463
  _globals['_RULE_RESOURCE']._serialized_end=1499
  _globals['_RULE_TYPE']._serialized_start=1501
  _globals['_RULE_TYPE']._serialized_end=1530
  _globals['_RULE_AMOUNTMODE']._serialized_start=1532
  _globals['_RULE_AMOUNTMODE']._serialized_end=1581
  _globals['_RULE_FAILOVERTYPE']._serialized_start=1583
  _globals['_RULE_FAILOVERTYPE']._serialized_end=1636
  _globals['_MATCHARGUMENT']._serialized_start=1639
  _globals['_MATCHARGUMENT']._serialized_end=1827
  _globals['_MATCHARGUMENT_TYPE']._serialized_start=1739
  _globals['_MATCHARGUMENT_TYPE']._serialized_end=1827
  _globals['_RATELIMITCLUSTER']._serialized_start=1829
  _globals['_RATELIMITCLUSTER']._serialized_end=1943
  _globals['_AMOUNT']._serialized_start=1946
  _globals['_AMOUNT']._serialized_end=2202
  _globals['_REPORT']._serialized_start=2204
  _globals['_REPORT']._serialized_end=2310
  _globals['_AMOUNTADJUSTER']._serialized_start=2312
  _globals['_AMOUNTADJUSTER']._serialized_end=2360
  _globals['_CLIMBCONFIG']._serialized_start=2363
  _globals['_CLIMBCONFIG']._serialized_end=3879
  _globals['_CLIMBCONFIG_METRICCONFIG']._serialized_start=2569
  _globals['_CLIMBCONFIG_METRICCONFIG']._serialized_end=2726
  _globals['_CLIMBCONFIG_TRIGGERPOLICY']._serialized_start=2729
  _globals['_CLIMBCONFIG_TRIGGERPOLICY']._serialized_end=3408
  _globals['_CLIMBCONFIG_TRIGGERPOLICY_ERRORRATE']._serialized_start=2865
  _globals['_CLIMBCONFIG_TRIGGERPOLICY_ERRORRATE']._serialized_end=3262
  _globals['_CLIMBCONFIG_TRIGGERPOLICY_ERRORRATE_SPECIALCONFIG']._serialized_start=3106
  _globals['_CLIMBCONFIG_TRIGGERPOLICY_ERRORRATE_SPECIALCONFIG']._serialized_end=3262
  _globals['_CLIMBCONFIG_TRIGGERPOLICY_SLOWRATE']._serialized_start=3265
  _globals['_CLIMBCONFIG_TRIGGERPOLICY_SLOWRATE']._serialized_end=3408
  _globals['_CLIMBCONFIG_CLIMBTHROTTLING']._serialized_start=3411
  _globals['_CLIMBCONFIG_CLIMBTHROTTLING']._serialized_end=3879
# @@protoc_insertion_point(module_scope)
