from ..config_manage import config_file_pb2 as _config_file_pb2
from ..config_manage import config_file_response_pb2 as _config_file_response_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
