# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nauth.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\"\x97\x01\n\x0cLoginRequest\x12+\n\x05owner\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08password\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x86\x02\n\rLoginResponse\x12\x36\n\x07user_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07user_id\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04role\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x08owner_id\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08owner_id\x12+\n\x05token\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x85\x05\n\x04User\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08password\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05owner\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06source\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12<\n\nauth_token\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nauth_token\x12>\n\x0ctoken_enable\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x0ctoken_enable\x12-\n\x07\x63omment\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x63time\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\tuser_type\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tuser_type\x12,\n\x06mobile\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x65mail\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xc2\x01\n\x12ModifyUserPassword\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12@\n\x0cold_password\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0cold_password\x12@\n\x0cnew_password\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0cnew_password\"f\n\x11UserGroupRelation\x12\x38\n\x08group_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08group_id\x12\x17\n\x05users\x18\x02 \x03(\x0b\x32\x08.v1.User\"\xfc\x03\n\tUserGroup\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05owner\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12<\n\nauth_token\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nauth_token\x12>\n\x0ctoken_enable\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x0ctoken_enable\x12-\n\x07\x63omment\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x63time\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\'\n\x08relation\x18\t \x01(\x0b\x32\x15.v1.UserGroupRelation\x12<\n\nuser_count\x18\n \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\nuser_count\"\xc1\x03\n\x0fModifyUserGroup\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05owner\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12<\n\nauth_token\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nauth_token\x12>\n\x0ctoken_enable\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x0ctoken_enable\x12-\n\x07\x63omment\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\radd_relations\x18\x07 \x01(\x0b\x32\x15.v1.UserGroupRelationR\radd_relations\x12\x41\n\x10remove_relations\x18\x08 \x01(\x0b\x32\x15.v1.UserGroupRelationR\x10remove_relations\"a\n\tPrincipal\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"I\n\nPrincipals\x12\x1c\n\x05users\x18\x01 \x03(\x0b\x32\r.v1.Principal\x12\x1d\n\x06groups\x18\x02 \x03(\x0b\x32\r.v1.Principal\"\x9e\x01\n\x15StrategyResourceEntry\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xf0\x01\n\x11StrategyResources\x12>\n\x0bstrategy_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0bstrategy_id\x12-\n\nnamespaces\x18\x02 \x03(\x0b\x32\x19.v1.StrategyResourceEntry\x12+\n\x08services\x18\x03 \x03(\x0b\x32\x19.v1.StrategyResourceEntry\x12?\n\rconfig_groups\x18\x04 \x03(\x0b\x32\x19.v1.StrategyResourceEntryR\rconfig_groups\"\x8e\x04\n\x0c\x41uthStrategy\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\"\n\nprincipals\x18\x03 \x01(\x0b\x32\x0e.v1.Principals\x12(\n\tresources\x18\x04 \x01(\x0b\x32\x15.v1.StrategyResources\x12\x1e\n\x06\x61\x63tion\x18\x05 \x01(\x0e\x32\x0e.v1.AuthAction\x12-\n\x07\x63omment\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05owner\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05\x63time\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05mtime\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12<\n\nauth_token\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nauth_token\x12\x46\n\x10\x64\x65\x66\x61ult_strategy\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x10\x64\x65\x66\x61ult_strategy\"\xdc\x03\n\x12ModifyAuthStrategy\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x0e\x61\x64\x64_principals\x18\x03 \x01(\x0b\x32\x0e.v1.PrincipalsR\x0e\x61\x64\x64_principals\x12<\n\x11remove_principals\x18\x04 \x01(\x0b\x32\x0e.v1.PrincipalsR\x11remove_principals\x12;\n\radd_resources\x18\x05 \x01(\x0b\x32\x15.v1.StrategyResourcesR\radd_resources\x12\x41\n\x10remove_resources\x18\x06 \x01(\x0b\x32\x15.v1.StrategyResourcesR\x10remove_resources\x12\x1e\n\x06\x61\x63tion\x18\x07 \x01(\x0e\x32\x0e.v1.AuthAction\x12-\n\x07\x63omment\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05owner\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue*+\n\nAuthAction\x12\r\n\tONLY_READ\x10\x00\x12\x0e\n\nREAD_WRITE\x10\x01*>\n\x0cResourceType\x12\x0e\n\nNamespaces\x10\x00\x12\x0c\n\x08Services\x10\x01\x12\x10\n\x0c\x43onfigGroups\x10\x02\x42\x82\x01\n1com.tencent.polaris.specification.api.v1.securityB\rSecurityProtoZ>github.com/polarismesh/specification/source/go/api/v1/securityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n1com.tencent.polaris.specification.api.v1.securityB\rSecurityProtoZ>github.com/polarismesh/specification/source/go/api/v1/security'
  _globals['_AUTHACTION']._serialized_start=3967
  _globals['_AUTHACTION']._serialized_end=4010
  _globals['_RESOURCETYPE']._serialized_start=4012
  _globals['_RESOURCETYPE']._serialized_end=4074
  _globals['_LOGINREQUEST']._serialized_start=51
  _globals['_LOGINREQUEST']._serialized_end=202
  _globals['_LOGINRESPONSE']._serialized_start=205
  _globals['_LOGINRESPONSE']._serialized_end=467
  _globals['_USER']._serialized_start=470
  _globals['_USER']._serialized_end=1115
  _globals['_MODIFYUSERPASSWORD']._serialized_start=1118
  _globals['_MODIFYUSERPASSWORD']._serialized_end=1312
  _globals['_USERGROUPRELATION']._serialized_start=1314
  _globals['_USERGROUPRELATION']._serialized_end=1416
  _globals['_USERGROUP']._serialized_start=1419
  _globals['_USERGROUP']._serialized_end=1927
  _globals['_MODIFYUSERGROUP']._serialized_start=1930
  _globals['_MODIFYUSERGROUP']._serialized_end=2379
  _globals['_PRINCIPAL']._serialized_start=2381
  _globals['_PRINCIPAL']._serialized_end=2478
  _globals['_PRINCIPALS']._serialized_start=2480
  _globals['_PRINCIPALS']._serialized_end=2553
  _globals['_STRATEGYRESOURCEENTRY']._serialized_start=2556
  _globals['_STRATEGYRESOURCEENTRY']._serialized_end=2714
  _globals['_STRATEGYRESOURCES']._serialized_start=2717
  _globals['_STRATEGYRESOURCES']._serialized_end=2957
  _globals['_AUTHSTRATEGY']._serialized_start=2960
  _globals['_AUTHSTRATEGY']._serialized_end=3486
  _globals['_MODIFYAUTHSTRATEGY']._serialized_start=3489
  _globals['_MODIFYAUTHSTRATEGY']._serialized_end=3965
# @@protoc_insertion_point(module_scope)
