from ..service_manage import client_pb2 as _client_pb2
from ..service_manage import service_pb2 as _service_pb2
from ..service_manage import request_pb2 as _request_pb2
from ..service_manage import response_pb2 as _response_pb2
from ..service_manage import heartbeat_pb2 as _heartbeat_pb2
from ..service_manage import contract_pb2 as _contract_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
