# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bmodel.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\"\x92\x01\n\x08Location\x12,\n\x06region\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04zone\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06\x63\x61mpus\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xb0\x02\n\x0bMatchString\x12-\n\x04type\x18\x01 \x01(\x0e\x32\x1f.v1.MatchString.MatchStringType\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\nvalue_type\x18\x03 \x01(\x0e\x32\x19.v1.MatchString.ValueTypeR\nvalue_type\"V\n\x0fMatchStringType\x12\t\n\x05\x45XACT\x10\x00\x12\t\n\x05REGEX\x10\x01\x12\x0e\n\nNOT_EQUALS\x10\x02\x12\x06\n\x02IN\x10\x03\x12\n\n\x06NOT_IN\x10\x04\x12\t\n\x05RANGE\x10\x05\"2\n\tValueType\x12\x08\n\x04TEXT\x10\x00\x12\r\n\tPARAMETER\x10\x01\x12\x0c\n\x08VARIABLE\x10\x02\"\x1c\n\nStringList\x12\x0e\n\x06values\x18\x01 \x03(\t\"\xb1\x01\n\x07Summary\x12\x30\n\x13total_service_count\x18\x01 \x01(\rR\x13total_service_count\x12@\n\x1btotal_health_instance_count\x18\x02 \x01(\rR\x1btotal_health_instance_count\x12\x32\n\x14total_instance_count\x18\x03 \x01(\rR\x14total_instance_count\":\n\x0b\x43lientLabel\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.v1.MatchStringBy\n.com.tencent.polaris.specification.api.v1.modelB\nModelProtoZ;github.com/polarismesh/specification/source/go/api/v1/modelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.com.tencent.polaris.specification.api.v1.modelB\nModelProtoZ;github.com/polarismesh/specification/source/go/api/v1/model'
  _globals['_LOCATION']._serialized_start=52
  _globals['_LOCATION']._serialized_end=198
  _globals['_MATCHSTRING']._serialized_start=201
  _globals['_MATCHSTRING']._serialized_end=505
  _globals['_MATCHSTRING_MATCHSTRINGTYPE']._serialized_start=367
  _globals['_MATCHSTRING_MATCHSTRINGTYPE']._serialized_end=453
  _globals['_MATCHSTRING_VALUETYPE']._serialized_start=455
  _globals['_MATCHSTRING_VALUETYPE']._serialized_end=505
  _globals['_STRINGLIST']._serialized_start=507
  _globals['_STRINGLIST']._serialized_end=535
  _globals['_SUMMARY']._serialized_start=538
  _globals['_SUMMARY']._serialized_end=715
  _globals['_CLIENTLABEL']._serialized_start=717
  _globals['_CLIENTLABEL']._serialized_end=775
# @@protoc_insertion_point(module_scope)
