# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..service_manage import service_pb2 as service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rrequest.proto\x12\x02v1\x1a\rservice.proto\"-\n\x0e\x44iscoverFilter\x12\x1b\n\x13OnlyHealthyInstance\x18\x01 \x01(\x08\"\xd0\x02\n\x0f\x44iscoverRequest\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.v1.DiscoverRequest.DiscoverRequestType\x12\x1c\n\x07service\x18\x02 \x01(\x0b\x32\x0b.v1.Service\x12\"\n\x06\x46ilter\x18\x1e \x01(\x0b\x32\x12.v1.DiscoverFilter\"\xbd\x01\n\x13\x44iscoverRequestType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08INSTANCE\x10\x01\x12\x0b\n\x07\x43LUSTER\x10\x02\x12\x0b\n\x07ROUTING\x10\x03\x12\x0e\n\nRATE_LIMIT\x10\x04\x12\x13\n\x0f\x43IRCUIT_BREAKER\x10\x05\x12\x0c\n\x08SERVICES\x10\x06\x12\x0e\n\nNAMESPACES\x10\x0c\x12\x12\n\x0e\x46\x41ULT_DETECTOR\x10\r\x12\x14\n\x10SERVICE_CONTRACT\x10\x0e\"\x04\x08\x07\x10\x0bJ\x04\x08\x03\x10\x05\x42\x8d\x01\n7com.tencent.polaris.specification.api.v1.service.manageB\x0cRequestProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.service.manageB\014RequestProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manage'
  _globals['_DISCOVERFILTER']._serialized_start=36
  _globals['_DISCOVERFILTER']._serialized_end=81
  _globals['_DISCOVERREQUEST']._serialized_start=84
  _globals['_DISCOVERREQUEST']._serialized_end=420
  _globals['_DISCOVERREQUEST_DISCOVERREQUESTTYPE']._serialized_start=225
  _globals['_DISCOVERREQUEST_DISCOVERREQUESTTYPE']._serialized_end=414
# @@protoc_insertion_point(module_scope)
