# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grpcapi.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..service_manage import client_pb2 as client__pb2
from ..service_manage import service_pb2 as service__pb2
from ..service_manage import request_pb2 as request__pb2
from ..service_manage import response_pb2 as response__pb2
from ..service_manage import heartbeat_pb2 as heartbeat__pb2
from ..service_manage import contract_pb2 as contract__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rgrpcapi.proto\x12\x02v1\x1a\x0c\x63lient.proto\x1a\rservice.proto\x1a\rrequest.proto\x1a\x0eresponse.proto\x1a\x0fheartbeat.proto\x1a\x0e\x63ontract.proto2\x87\x02\n\x0bPolarisGRPC\x12*\n\x0cReportClient\x12\n.v1.Client\x1a\x0c.v1.Response\"\x00\x12\x30\n\x10RegisterInstance\x12\x0c.v1.Instance\x1a\x0c.v1.Response\"\x00\x12\x32\n\x12\x44\x65registerInstance\x12\x0c.v1.Instance\x1a\x0c.v1.Response\"\x00\x12;\n\x08\x44iscover\x12\x13.v1.DiscoverRequest\x1a\x14.v1.DiscoverResponse\"\x00(\x01\x30\x01\x12)\n\tHeartbeat\x12\x0c.v1.Instance\x1a\x0c.v1.Response\"\x00\x32\xf5\x01\n\x14PolarisHeartbeatGRPC\x12\x45\n\x0e\x42\x61tchHeartbeat\x12\x15.v1.HeartbeatsRequest\x1a\x16.v1.HeartbeatsResponse\"\x00(\x01\x30\x01\x12J\n\x11\x42\x61tchGetHeartbeat\x12\x18.v1.GetHeartbeatsRequest\x1a\x19.v1.GetHeartbeatsResponse\"\x00\x12J\n\x11\x42\x61tchDelHeartbeat\x12\x18.v1.DelHeartbeatsRequest\x1a\x19.v1.DelHeartbeatsResponse\"\x00\x32Z\n\x1aPolarisServiceContractGRPC\x12<\n\x15ReportServiceContract\x12\x13.v1.ServiceContract\x1a\x0c.v1.Response\"\x00\x42\x93\x01\n7com.tencent.polaris.specification.api.v1.service.manageB\x12PolarisGRPCServiceZDgithub.com/polarismesh/specification/source/go/api/v1/service_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'grpcapi_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.service.manageB\022PolarisGRPCServiceZDgithub.com/polarismesh/specification/source/go/api/v1/service_manage'
  _globals['_POLARISGRPC']._serialized_start=115
  _globals['_POLARISGRPC']._serialized_end=378
  _globals['_POLARISHEARTBEATGRPC']._serialized_start=381
  _globals['_POLARISHEARTBEATGRPC']._serialized_end=626
  _globals['_POLARISSERVICECONTRACTGRPC']._serialized_start=628
  _globals['_POLARISSERVICECONTRACTGRPC']._serialized_end=718
# @@protoc_insertion_point(module_scope)
