# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: config_file.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from ..model import model_pb2 as model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63onfig_file.proto\x12\x02v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x0bmodel.proto\"\xeb\x07\n\x0f\x43onfigFileGroup\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63omment\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tcreate_by\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bmodify_time\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tmodify_by\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tfileCount\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x38\n\x08user_ids\x18\n \x03(\x0b\x32\x1c.google.protobuf.StringValueR\x08user_ids\x12:\n\tgroup_ids\x18\x0b \x03(\x0b\x32\x1c.google.protobuf.StringValueR\tgroup_ids\x12\x46\n\x0fremove_user_ids\x18\r \x03(\x0b\x32\x1c.google.protobuf.StringValueR\x0fremove_user_ids\x12H\n\x10remove_group_ids\x18\x0e \x03(\x0b\x32\x1c.google.protobuf.StringValueR\x10remove_group_ids\x12,\n\x08\x65\x64itable\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\x05owner\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x62usiness\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\ndepartment\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\x08metadata\x18\x13 \x03(\x0b\x32!.v1.ConfigFileGroup.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xac\x06\n\nConfigFile\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05group\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63ontent\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06\x66ormat\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63omment\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06status\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1f\n\x04tags\x18\t \x03(\x0b\x32\x11.v1.ConfigFileTag\x12\x31\n\x0b\x63reate_time\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tcreate_by\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bmodify_time\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tmodify_by\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0crelease_time\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\nrelease_by\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\tencrypted\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0c\x65ncrypt_algo\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"g\n\rConfigFileTag\x12)\n\x03key\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x80\x07\n\x11\x43onfigFileRelease\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05group\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tfile_name\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63ontent\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63omment\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12)\n\x03md5\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07version\x18\t \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x31\n\x0b\x63reate_time\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tcreate_by\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bmodify_time\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tmodify_by\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1f\n\x04tags\x18\x0e \x03(\x0b\x32\x11.v1.ConfigFileTag\x12*\n\x06\x61\x63tive\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x06\x66ormat\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13release_description\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04type\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12$\n\x0b\x62\x65ta_labels\x18\x13 \x03(\x0b\x32\x0f.v1.ClientLabel\"\xe2\x06\n\x18\x43onfigFileReleaseHistory\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tnamespace\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05group\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tfile_name\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63ontent\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06\x66ormat\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63omment\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12)\n\x03md5\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04type\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06status\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1f\n\x04tags\x18\x0c \x03(\x0b\x32\x11.v1.ConfigFileTag\x12\x31\n\x0b\x63reate_time\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tcreate_by\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bmodify_time\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tmodify_by\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06reason\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13release_description\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xbe\x03\n\x12\x43onfigFileTemplate\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06\x66ormat\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63omment\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0b\x63reate_time\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tcreate_by\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bmodify_time\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tmodify_by\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\x9e\x04\n\x14\x43lientConfigFileInfo\x12/\n\tnamespace\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05group\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tfile_name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63ontent\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07version\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12)\n\x03md5\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1f\n\x04tags\x18\x07 \x03(\x0b\x32\x11.v1.ConfigFileTag\x12-\n\tencrypted\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\npublic_key\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12@\n\x0crelease_time\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0crelease_time\"\xb2\x01\n\x1c\x43lientWatchConfigFileRequest\x12/\n\tclient_ip\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0cservice_name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x0bwatch_files\x18\x03 \x03(\x0b\x32\x18.v1.ClientConfigFileInfo\"\xa5\x01\n\x17\x43onfigFileExportRequest\x12/\n\tnamespace\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06groups\x18\x02 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05names\x18\x03 \x03(\x0b\x32\x1c.google.protobuf.StringValue\"\xe8\x04\n\x15\x43onfigFilePublishInfo\x12@\n\x0crelease_name\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0crelease_name\x12/\n\tnamespace\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05group\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\tfile_name\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tfile_name\x12-\n\x07\x63ontent\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63omment\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06\x66ormat\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12N\n\x13release_description\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x13release_description\x12:\n\tcreate_by\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tcreate_by\x12:\n\tmodify_by\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tmodify_by\x12\x1f\n\x04tags\x18\x0e \x03(\x0b\x32\x11.v1.ConfigFileTag\"\x94\x02\n\x16\x43onfigFileGroupRequest\x12.\n\x08revision\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x41\n\x11\x63onfig_file_group\x18\x02 \x01(\x0b\x32\x13.v1.ConfigFileGroupR\x11\x63onfig_file_group\x12R\n\rclient_labels\x18\x0c \x03(\x0b\x32,.v1.ConfigFileGroupRequest.ClientLabelsEntryR\rclient_labels\x1a\x33\n\x11\x43lientLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"q\n\x15\x43onfigDiscoverRequest\x12$\n\x04type\x18\x01 \x01(\x0e\x32\x16.v1.ConfigDiscoverType\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\r\n\x05group\x18\x03 \x01(\t\x12\x10\n\x08revision\x18\x04 \x01(\t\"\xb5\x02\n\x16\x43onfigDiscoverResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0c\n\x04info\x18\x02 \x01(\t\x12\x10\n\x08revision\x18\x03 \x01(\t\x12$\n\x04type\x18\x04 \x01(\x0e\x32\x16.v1.ConfigDiscoverType\x12:\n\x0b\x63onfig_file\x18\x05 \x01(\x0b\x32\x18.v1.ClientConfigFileInfoR\x0b\x63onfig_file\x12\x46\n\x11\x63onfig_file_names\x18\x06 \x03(\x0b\x32\x18.v1.ClientConfigFileInfoR\x11\x63onfig_file_names\x12\x43\n\x12\x63onfig_file_groups\x18\x07 \x03(\x0b\x32\x13.v1.ConfigFileGroupR\x12\x63onfig_file_groups*[\n\x12\x43onfigDiscoverType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0f\n\x0b\x43ONFIG_FILE\x10\x01\x12\x14\n\x10\x43ONFIG_FILE_LIST\x10\x02\x12\x11\n\rCONFIG_GROUPS\x10\x03\x42\x8e\x01\n6com.tencent.polaris.specification.api.v1.config.manageB\x0f\x43onfigFileProtoZCgithub.com/polarismesh/specification/source/go/api/v1/config_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'config_file_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n6com.tencent.polaris.specification.api.v1.config.manageB\017ConfigFileProtoZCgithub.com/polarismesh/specification/source/go/api/v1/config_manage'
  _CONFIGFILEGROUP_METADATAENTRY._options = None
  _CONFIGFILEGROUP_METADATAENTRY._serialized_options = b'8\001'
  _CONFIGFILEGROUPREQUEST_CLIENTLABELSENTRY._options = None
  _CONFIGFILEGROUPREQUEST_CLIENTLABELSENTRY._serialized_options = b'8\001'
  _globals['_CONFIGDISCOVERTYPE']._serialized_start=6432
  _globals['_CONFIGDISCOVERTYPE']._serialized_end=6523
  _globals['_CONFIGFILEGROUP']._serialized_start=71
  _globals['_CONFIGFILEGROUP']._serialized_end=1074
  _globals['_CONFIGFILEGROUP_METADATAENTRY']._serialized_start=1027
  _globals['_CONFIGFILEGROUP_METADATAENTRY']._serialized_end=1074
  _globals['_CONFIGFILE']._serialized_start=1077
  _globals['_CONFIGFILE']._serialized_end=1889
  _globals['_CONFIGFILETAG']._serialized_start=1891
  _globals['_CONFIGFILETAG']._serialized_end=1994
  _globals['_CONFIGFILERELEASE']._serialized_start=1997
  _globals['_CONFIGFILERELEASE']._serialized_end=2893
  _globals['_CONFIGFILERELEASEHISTORY']._serialized_start=2896
  _globals['_CONFIGFILERELEASEHISTORY']._serialized_end=3762
  _globals['_CONFIGFILETEMPLATE']._serialized_start=3765
  _globals['_CONFIGFILETEMPLATE']._serialized_end=4211
  _globals['_CLIENTCONFIGFILEINFO']._serialized_start=4214
  _globals['_CLIENTCONFIGFILEINFO']._serialized_end=4756
  _globals['_CLIENTWATCHCONFIGFILEREQUEST']._serialized_start=4759
  _globals['_CLIENTWATCHCONFIGFILEREQUEST']._serialized_end=4937
  _globals['_CONFIGFILEEXPORTREQUEST']._serialized_start=4940
  _globals['_CONFIGFILEEXPORTREQUEST']._serialized_end=5105
  _globals['_CONFIGFILEPUBLISHINFO']._serialized_start=5108
  _globals['_CONFIGFILEPUBLISHINFO']._serialized_end=5724
  _globals['_CONFIGFILEGROUPREQUEST']._serialized_start=5727
  _globals['_CONFIGFILEGROUPREQUEST']._serialized_end=6003
  _globals['_CONFIGFILEGROUPREQUEST_CLIENTLABELSENTRY']._serialized_start=5952
  _globals['_CONFIGFILEGROUPREQUEST_CLIENTLABELSENTRY']._serialized_end=6003
  _globals['_CONFIGDISCOVERREQUEST']._serialized_start=6005
  _globals['_CONFIGDISCOVERREQUEST']._serialized_end=6118
  _globals['_CONFIGDISCOVERRESPONSE']._serialized_start=6121
  _globals['_CONFIGDISCOVERRESPONSE']._serialized_end=6430
# @@protoc_insertion_point(module_scope)
