# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: contract.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x63ontract.proto\x12\x02v1\"\xf0\x01\n\x0fServiceContract\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x0f\n\x07service\x18\x04 \x01(\t\x12\x10\n\x08protocol\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\t\x12\x10\n\x08revision\x18\x07 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x08 \x01(\t\x12+\n\ninterfaces\x18\t \x03(\x0b\x32\x17.v1.InterfaceDescriptor\x12\r\n\x05\x63time\x18\n \x01(\t\x12\r\n\x05mtime\x18\x0b \x01(\t\x12\x0e\n\x06status\x18\x0c \x01(\t\"\xdf\x01\n\x13InterfaceDescriptor\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12.\n\x06source\x18\x05 \x01(\x0e\x32\x1e.v1.InterfaceDescriptor.Source\x12\x10\n\x08revision\x18\x06 \x01(\t\x12\r\n\x05\x63time\x18\x07 \x01(\t\x12\r\n\x05mtime\x18\x08 \x01(\t\"-\n\x06Source\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06Manual\x10\x01\x12\n\n\x06\x43lient\x10\x02\x42\x95\x01\n7com.tencent.polaris.specification.api.v1.service.manageB\x14ServiceContractProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'contract_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.service.manageB\024ServiceContractProtoZDgithub.com/polarismesh/specification/source/go/api/v1/service_manage'
  _globals['_SERVICECONTRACT']._serialized_start=23
  _globals['_SERVICECONTRACT']._serialized_end=263
  _globals['_INTERFACEDESCRIPTOR']._serialized_start=266
  _globals['_INTERFACEDESCRIPTOR']._serialized_end=489
  _globals['_INTERFACEDESCRIPTOR_SOURCE']._serialized_start=444
  _globals['_INTERFACEDESCRIPTOR_SOURCE']._serialized_end=489
# @@protoc_insertion_point(module_scope)
