# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: heartbeat.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..service_manage import service_pb2 as service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fheartbeat.proto\x12\x02v1\x1a\rservice.proto\"|\n\x0fHeartbeatRecord\x12\x1f\n\ninstanceId\x18\x01 \x01(\tR\x0binstance_id\x12,\n\x10lastHeartbeatSec\x18\x06 \x01(\x03R\x12last_heartbeat_sec\x12\x14\n\x05\x65xist\x18\x07 \x01(\x08R\x05\x65xistJ\x04\x08\x02\x10\x06\"\x94\x01\n\x11InstanceHeartbeat\x12\x1f\n\ninstanceId\x18\x01 \x01(\tR\x0binstance_id\x12\x18\n\x07service\x18\x02 \x01(\tR\x07service\x12\x1c\n\tnamespace\x18\x03 \x01(\tR\tnamespace\x12\x12\n\x04host\x18\x04 \x01(\tR\x04host\x12\x12\n\x04port\x18\x05 \x01(\rR\x04port\"J\n\x11HeartbeatsRequest\x12\x35\n\nheartbeats\x18\x01 \x03(\x0b\x32\x15.v1.InstanceHeartbeatR\nheartbeats\"\x14\n\x12HeartbeatsResponse\"9\n\x14GetHeartbeatsRequest\x12!\n\x0binstanceIds\x18\x01 \x03(\tR\x0cinstance_ids\"F\n\x15GetHeartbeatsResponse\x12-\n\x07records\x18\x01 \x03(\x0b\x32\x13.v1.HeartbeatRecordR\x07records\"9\n\x14\x44\x65lHeartbeatsRequest\x12!\n\x0binstanceIds\x18\x01 \x03(\tR\x0cinstance_ids\"3\n\x15\x44\x65lHeartbeatsResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\r\x12\x0c\n\x04info\x18\x02 \x01(\tB\x7f\n7com.tencent.polaris.specification.api.v1.service.manageZDgithub.com/polarismesh/specification/source/go/api/v1/service_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'heartbeat_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.service.manageZDgithub.com/polarismesh/specification/source/go/api/v1/service_manage'
  _globals['_HEARTBEATRECORD']._serialized_start=38
  _globals['_HEARTBEATRECORD']._serialized_end=162
  _globals['_INSTANCEHEARTBEAT']._serialized_start=165
  _globals['_INSTANCEHEARTBEAT']._serialized_end=313
  _globals['_HEARTBEATSREQUEST']._serialized_start=315
  _globals['_HEARTBEATSREQUEST']._serialized_end=389
  _globals['_HEARTBEATSRESPONSE']._serialized_start=391
  _globals['_HEARTBEATSRESPONSE']._serialized_end=411
  _globals['_GETHEARTBEATSREQUEST']._serialized_start=413
  _globals['_GETHEARTBEATSREQUEST']._serialized_end=470
  _globals['_GETHEARTBEATSRESPONSE']._serialized_start=472
  _globals['_GETHEARTBEATSRESPONSE']._serialized_end=542
  _globals['_DELHEARTBEATSREQUEST']._serialized_start=544
  _globals['_DELHEARTBEATSREQUEST']._serialized_end=601
  _globals['_DELHEARTBEATSRESPONSE']._serialized_start=603
  _globals['_DELHEARTBEATSRESPONSE']._serialized_end=654
# @@protoc_insertion_point(module_scope)
